@@ -2,6 +2,8 @@ import unplate.compile as unplate_compile
 import unplate.tokenize_util as tku
 import unplate.util
 
+# export UnplateSyntaxError
+UnplateSyntaxError = unplate_compile.UnplateSyntaxError
 
 def template(*args, **kwargs):
   raise Exception("Something's gone wrong. You should never actually invoke unplate.template().")
@@ -36,15 +38,26 @@ with False in order to prevent infinite recursion.
 
 true = True
 
+
 def compile(file_loc):
 
-  tokens = tku.tokenize_file(file_loc)
+  with open(file_loc, 'r') as f:
+    code = f.read()
 
+  return compile_code(code, file_loc=file_loc)
+
+
+def compile_anon(code):
+  return compile_code(code, file_loc='<anonymous>')
+
+
+def compile_code(code, *, file_loc):
+
+  tokens = tku.tokenize_string(code)
   compiled_tokens = unplate_compile.compile_top(tokens, file_loc=file_loc)
 
   # Remove the wrapper
   unplate_wrapper = tku.tokenize_expr('unplate.true')
-  assert util.has_sublist(compiled_tokens, unplate_wrapper)
   true_token = tku.tokenize_one('False')
   compiled_tokens = util.replace_sublist(compiled_tokens, unplate_wrapper, [true_token])
 
